import { ChangeEvent, FormEvent, useState } from "react";
import { Box, Button, Grid, TextField } from "@mui/material";
import { CreateProductType } from "../../interfaces/IProduct.ts";

interface IState {
  name: string;
  price: string;
  description: string;
}

interface IProps {
  onSubmit: (data: CreateProductType) => void;
}
const ProductForm = ({ onSubmit }: IProps) => {
  const [state, setState] = useState<IState>({
    name: "",
    price: "",
    description: "",
  });

  const submitFormHandler = (e: FormEvent<HTMLFormElement>) => {
    e.preventDefault();

    const newProduct: CreateProductType = {
      name: state.name,
      description: state.description,
      price: parseInt(state.price),
    };

    onSubmit(newProduct);
  };

  const inputChangeHandler = (e: ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target;
    setState((prevState) => {
      return { ...prevState, [name]: value };
    });
  };

  return (
    <Box
      component="form"
      autoComplete="off"
      onSubmit={submitFormHandler}
      paddingY={2}
    >
      <Grid container direction="column" spacing={2}>
        <Grid item xs>
          <TextField
            fullWidth
            variant="outlined"
            id="name"
            label="Title"
            value={state.name}
            onChange={inputChangeHandler}
            name="name"
          />
        </Grid>

        <Grid item xs>
          <TextField
            fullWidth
            variant="outlined"
            id="price"
            label="Price"
            value={state.price}
            onChange={inputChangeHandler}
            name="price"
          />
        </Grid>

        <Grid item xs>
          <TextField
            fullWidth
            variant="outlined"
            id="description"
            label="Description"
            value={state.description}
            onChange={inputChangeHandler}
            name="description"
          />
        </Grid>

        <Grid item xs>
          <Button type="submit" color="primary" variant="contained">
            Create
          </Button>
        </Grid>
      </Grid>
    </Box>
  );
};

export default ProductForm;
